import { Construct } from "constructs";
import { CfnPrivateEndpoint, PrivateEndpoint } from "../../index";
import { AtlasBasic } from "../atlas-basic";
import { AtlasBasicProps } from "../common/props";
/**
 * @description
 * @export
 * @class AtlasBasicPrivateEndpoint
 * @extends {Construct}
 */
export declare class AtlasBasicPrivateEndpoint extends Construct {
    readonly atlasBasic: AtlasBasic;
    readonly privateEndpoint: CfnPrivateEndpoint;
    /**
     * Creates an instance of AtlasBasicPrivateEndpoint.
     * @param {Construct} scope
     * @param {string} id
     * @param {AtlasBasicPrivateEndpointProps} props
     * @memberof AtlasBasicPrivateEndpoint
     */
    constructor(scope: Construct, id: string, props: AtlasBasicPrivateEndpointProps);
}
/**
 * @description
 * @export
 * @interface AtlasBasicPrivateEndpointProps
 */
export interface AtlasBasicPrivateEndpointProps {
    readonly profile?: string;
    /**
     * @description AWS Region
     * @type {string}
     * @default us-east-1
     * @memberof AtlasPrivateEndpointProps
     */
    readonly region?: string;
    /**
     * @description
     * @type {AtlasBasicProps}
     * @memberof AtlasPrivateEndpointProps
     */
    readonly atlasBasicProps: AtlasBasicProps;
    /**
     * @description
     * @type {CfnPrivateEndpointProps}
     * @memberof AtlasPrivateEndpointProps
     */
    readonly privateEndpointProps: PrivateEndpointProps;
}
/**
 * @description
 * @export
 * @interface PrivateEndpointProps
 */
export interface PrivateEndpointProps {
    /**
     * @description Name of the AWS PrivateLink endpoint service. Atlas returns null while it is creating the endpoint service.
     * @type {string}
     * @memberof PrivateEndpointProps
     */
    readonly endpointServiceName?: string;
    /**
     * @description Error message pertaining to the AWS PrivateLink connection. Returns null if there are no errors.
     * @type {string}
     * @memberof PrivateEndpointProps
     */
    readonly errorMessage?: string;
    /**
     * @description Status of the Atlas PrivateEndpoint service connection
     * @type {string}
     * @memberof PrivateEndpointProps
     */
    readonly status?: string;
    /**
     * @description Unique 24-hexadecimal digit string that identifies your project.
     * @type {string}
     * @memberof PrivateEndpointProps
     */
    readonly groupId?: string;
    /**
     * @description
     * @type {string}
     * @memberof PrivateEndpointProps
     */
    readonly region?: string;
    /**
     * @description
     * @type {PrivateEndpoint[]}
     * @memberof PrivateEndpointProps
     */
    readonly privateEndpoints?: PrivateEndpoint[];
}
